GenericFonts

Struct GenericFonts 

#[non_exhaustive]
pub struct GenericFonts {}
Generic fonts configuration for the app.

This type can be accessed from the FONTS service.

Defaults

By default the serif, sans_serif, monospace, cursive and fantasy are set to their own generic name, this delegates the resolution to the operating system. The set_* methods can be used to override the default.

The default fallback font is “Segoe UI Symbol” for Windows, “Standard Symbols PS” for Linux and “sans-serif” for others.

See also FontNames::system_ui for the default font selection for system-ui.

Implementations

Source

impl GenericFonts

pub fn serif(&self, lang: &Lang) -> FontName

Gets the serif font for the given language.

Returns a font name for the best lang match.

Note that the returned name can still be the generic "serif", this delegates the resolution to the operating system.

pub fn set_serif<F: Into<FontName>>(&self, lang: Lang, font_name: F)

Sets the serif font for the given language.

The change is applied for the next update.

Use lang!(und) to set name used when no language matches.

pub fn sans_serif(&self, lang: &Lang) -> FontName

Gets the sans-serif font for the given language.

Returns a font name for the best lang match.

Note that the returned name can still be the generic "sans-serif", this delegates the resolution to the operating system.

pub fn set_sans_serif<F: Into<FontName>>(&self, lang: Lang, font_name: F)

Sets the sans-serif font for the given language.

The change is applied for the next update.

Use lang!(und) to set name used when no language matches.

pub fn monospace(&self, lang: &Lang) -> FontName

Gets the monospace font for the given language.

Returns a font name for the best lang match.

Note that the returned name can still be the generic "monospace", this delegates the resolution to the operating system.

pub fn set_monospace<F: Into<FontName>>(&self, lang: Lang, font_name: F)

Sets the monospace font for the given language.

The change is applied for the next update.

Use lang!(und) to set name used when no language matches.

pub fn cursive(&self, lang: &Lang) -> FontName

Gets the cursive font for the given language.

Returns a font name for the best lang match.

Note that the returned name can still be the generic "cursive", this delegates the resolution to the operating system.

pub fn set_cursive<F: Into<FontName>>(&self, lang: Lang, font_name: F)

Sets the cursive font for the given language.

The change is applied for the next update.

Use lang!(und) to set name used when no language matches.

pub fn fantasy(&self, lang: &Lang) -> FontName

Gets the fantasy font for the given language.

Returns a font name for the best lang match.

Note that the returned name can still be the generic "fantasy", this delegates the resolution to the operating system.

pub fn set_fantasy<F: Into<FontName>>(&self, lang: Lang, font_name: F)

Sets the fantasy font for the given language.

The change is applied for the next update.

Use lang!(und) to set name used when no language matches.

pub fn system_ui(&self, lang: &Lang) -> FontNames

Gets the “system-ui” font for the given language.

Returns a font name list for the best lang match.

Note that the returned names can still contain the generic "system-ui", this delegates the resolution to the operating system.

pub fn set_system_ui(&self, lang: Lang, font_names: impl Into<FontNames>)

Sets the “system-ui” fonts for a the given language.

The change is applied for the next update.

Use lang!(und) to set fonts used when no language matches.

pub fn fallback(&self, lang: &Lang) -> FontName

Gets the ultimate fallback font used when none of the other fonts support a glyph.

Returns a font name.

pub fn set_fallback<F: Into<FontName>>(&self, lang: Lang, font_name: F)

Sets the ultimate fallback font used when none of other fonts support a glyph.

The change applies for the next update.

Use lang!(und) to set name used when no language matches.

pub fn resolve(&self, name: &FontName, lang: &Lang) -> Option<FontName>

Returns the font name registered for the generic name and lang.

Returns None if name if not one of the generic font names.

Note that this does not resolve "system-ui", use resolve_list for that.

pub fn resolve_list(&self, names: &[FontName], lang: &Lang) -> Option<FontNames>

Returns a new list if any name in names can resolve.